@@ -1,12 +1,13 @@
 import click
 
-from . import core, version
+from . import core
+from pkg_resources import get_distribution
 
 
 def _print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
-    click.echo(version.__version__)
+    click.echo(get_distribution(__name__.split('.')[0]).version)
     ctx.exit()
 
 
